% tinyrox says don't edit this manually, but it can't stop you!
\name{format_age}
\alias{format_age}
\title{Format an age in seconds as a compact string (e.g. "12s", "3m", "2h").}
\usage{
format_age(seconds)
}
\description{
Format an age in seconds as a compact string (e.g. "12s", "3m", "2h").
}
\keyword{internal}
