% tinyrox says don't edit this manually, but it can't stop you!
\name{format_tokens}
\alias{format_tokens}
\title{Format a token count for display (K / M suffixes).}
\usage{
format_tokens(n)
}
\arguments{
\item{n}{Token count.}
}
\value{
Character.
}
\description{
Format a token count for display (K / M suffixes).
}
\keyword{internal}
