% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_kill_subagent}
\alias{tool_kill_subagent}
\title{Terminate a running subagent.}
\usage{
tool_kill_subagent(id)
}
\arguments{
\item{id}{(character) Subagent ID to terminate.}
}
\value{
An MCP tool-result list.
}
\description{
Terminate a running subagent.
}
\keyword{internal}
