% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_web_search}
\alias{tool_web_search}
\title{Search the web using Tavily API.}
\usage{
tool_web_search(query, max_results = 5L)
}
\arguments{
\item{query}{(character) Search query.}

\item{max_results}{(integer) Max results to return.}
}
\value{
An MCP tool-result list.
}
\description{
Search the web using Tavily API.
}
\keyword{internal}
