% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_git_status}
\alias{tool_git_status}
\title{Show git working tree status.}
\usage{
tool_git_status(path = ".")
}
\arguments{
\item{path}{(character) Repository path.}
}
\value{
An MCP tool-result list.
}
\description{
Show git working tree status.
}
\keyword{internal}
