% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_r_help}
\alias{tool_r_help}
\title{Get R package documentation via saber (exports, function help).}
\usage{
tool_r_help(topic, package = NULL)
}
\arguments{
\item{topic}{(character) Package or function name.}

\item{package}{(character) Package to search in (optional).}
}
\value{
An MCP tool-result list.
}
\description{
Get R package documentation via saber (exports, function help).
}
\keyword{internal}
