% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_fetch_url}
\alias{tool_fetch_url}
\title{Fetch the contents of a URL and return the response body.}
\usage{
tool_fetch_url(url, max_chars = 8000L)
}
\arguments{
\item{url}{(character) URL to fetch.}

\item{max_chars}{(integer) Maximum number of characters to return.}
}
\value{
An MCP tool-result list.
}
\description{
Fetch the contents of a URL and return the response body.
}
\keyword{internal}
