% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_list_subagents}
\alias{tool_list_subagents}
\title{List all active subagents.}
\usage{
tool_list_subagents()
}
\value{
An MCP tool-result list.
}
\description{
List all active subagents.
}
\keyword{internal}
