% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_bg_status}
\alias{tool_bg_status}
\title{Check status and output of background processes.}
\usage{
tool_bg_status()
}
\value{
An MCP tool-result list.
}
\description{
Check status and output of background processes.
}
\keyword{internal}
