% tinyrox says don't edit this manually, but it can't stop you!
\name{tool_bg_kill}
\alias{tool_bg_kill}
\title{Kill a background process by id.}
\usage{
tool_bg_kill(id)
}
\arguments{
\item{id}{(character) Process id (e.g. bg_1).}
}
\value{
An MCP tool-result list.
}
\description{
Kill a background process by id.
}
\keyword{internal}
