% tinyrox says don't edit this manually, but it can't stop you!
\docType{package}
\name{corteza-package}
\alias{corteza}
\alias{corteza-package}
\title{\packageTitle{corteza}}
\description{\packageDescription{corteza}}
\section{Package Content}{\packageIndices{corteza}}
\author{\packageAuthor{corteza}}
\section{Maintainer}{\packageMaintainer{corteza}}
\keyword{internal}
